@@ -132,7 +132,7 @@ stepFWD <- function(start.model, p.value = 0.05, db, reg.type = "ols", check.sta
 	if	(length(rf.c) > 0) {
 		for	(i in 1:rf.cl) {
 			rf.c.l <- rf.c[i]
-	 		cat.o <- summary.tbl(tbl = db, x = rf.c.l, y = target)
+	 		cat.o <- summ.tbl(tbl = db, x = rf.c.l, y = target)
 			cat.o$bin <- as.character(cat.o$bin)
 			cat.o <- cbind.data.frame(rf = rf.c.l, cat.o)
 			pct.check <- any(cat.o$pct.o < 0.05)
@@ -386,7 +386,7 @@ check.names <- function(x = names(db)) {
 return(x.c)
 }
 #summary table 
-summary.tbl <- function(tbl, x, y) {
+summ.tbl <- function(tbl, x, y) {
 	if	(!is.data.frame(tbl)) {
 		stop("tbl is not a data frame.")
 		}
